@@ -3,8 +3,8 @@
 
 
 def lexer_scan(extensions):
-    """ Scans extensions for ``lexer_rules`` and ``preprocessors``
-        attributes.
+    """Scans extensions for ``lexer_rules`` and ``preprocessors``
+    attributes.
     """
     lexer_rules = {}
     preprocessors = []
@@ -24,26 +24,25 @@ def lexer_scan(extensions):
 
 
 class Lexer(object):
-    """ Tokenizes input source per rules supplied.
-    """
+    """Tokenizes input source per rules supplied."""
 
     def __init__(
         self, lexer_rules, preprocessors=None, postprocessors=None, **ignore
     ):
-        """ Initializes with ``rules``. Rules must be a list of
-            two elements tuple: ``(regex, tokenizer)`` where
-            tokenizer if a callable of the following contract::
+        """Initializes with ``rules``. Rules must be a list of
+        two elements tuple: ``(regex, tokenizer)`` where
+        tokenizer if a callable of the following contract::
 
-            def tokenizer(match):
-                return end_index, token, value
+        def tokenizer(match):
+            return end_index, token, value
         """
         self.rules = lexer_rules
         self.preprocessors = preprocessors or []
         self.postprocessors = postprocessors or []
 
     def tokenize(self, source):
-        """ Translates ``source`` accoring to lexer rules into
-            an iteratable of tokens.
+        """Translates ``source`` accoring to lexer rules into
+        an iteratable of tokens.
         """
         for preprocessor in self.preprocessors:
             source = preprocessor(source)
