@@ -8,10 +8,10 @@ import time
 
 
 class FileLoader(object):
-    """ Loads templates from file system.
+    """Loads templates from file system.
 
-        ``directories`` - search path of directories to scan for template.
-        ``encoding`` - decode template content per encoding.
+    ``directories`` - search path of directories to scan for template.
+    ``encoding`` - decode template content per encoding.
     """
 
     def __init__(self, directories, encoding="UTF-8"):
@@ -25,8 +25,8 @@ class FileLoader(object):
         self.encoding = encoding
 
     def list_names(self):
-        """ Return a list of names relative to directories. Ignores any files
-            and directories that start with dot.
+        """Return a list of names relative to directories. Ignores any files
+        and directories that start with dot.
         """
         names = []
         for path in self.searchpath:
@@ -47,8 +47,7 @@ class FileLoader(object):
         return tuple(sorted(names))
 
     def get_fullname(self, name):
-        """ Returns a full path by a template name.
-        """
+        """Returns a full path by a template name."""
         for path in self.searchpath:
             filename = os.path.join(path, name)
             if not os.path.exists(filename):
@@ -60,8 +59,7 @@ class FileLoader(object):
             None
 
     def load(self, name):
-        """ Loads a template by name from file system.
-        """
+        """Loads a template by name from file system."""
         filename = self.get_fullname(name)
         if filename:
             f = open(filename, "rb")
@@ -73,46 +71,41 @@ class FileLoader(object):
 
 
 class DictLoader(object):
-    """ Loads templates from python dictionary.
+    """Loads templates from python dictionary.
 
-        ``templates`` - a dict where key corresponds to template name and
-        value to template content.
+    ``templates`` - a dict where key corresponds to template name and
+    value to template content.
     """
 
     def __init__(self, templates):
         self.templates = templates
 
     def list_names(self):
-        """ List all keys from internal dict.
-        """
+        """List all keys from internal dict."""
         return tuple(sorted(self.templates.keys()))
 
     def load(self, name):
-        """ Returns template by name.
-        """
+        """Returns template by name."""
         if name not in self.templates:
             return None
         return self.templates[name]
 
 
 class ChainLoader(object):
-    """ Loads templates from ``loaders`` until first succeed.
-    """
+    """Loads templates from ``loaders`` until first succeed."""
 
     def __init__(self, loaders):
         self.loaders = loaders
 
     def list_names(self):
-        """ Returns as list of names from all loaders.
-        """
+        """Returns as list of names from all loaders."""
         names = set()
         for loader in self.loaders:
             names |= set(loader.list_names())
         return tuple(sorted(names))
 
     def load(self, name):
-        """ Returns template by name from the first loader that succeed.
-        """
+        """Returns template by name from the first loader that succeed."""
         for loader in self.loaders:
             source = loader.load(name)
             if source is not None:
@@ -121,8 +114,7 @@ class ChainLoader(object):
 
 
 class PreprocessLoader(object):
-    """ Performs preprocessing of loaded template.
-    """
+    """Performs preprocessing of loaded template."""
 
     def __init__(self, engine, ctx=None):
         self.engine = engine
@@ -136,12 +128,12 @@ class PreprocessLoader(object):
 
 
 def autoreload(engine, enabled=True):
-    """ Auto reload template if changes are detected in file.
+    """Auto reload template if changes are detected in file.
 
-        Limitation: master (inherited), imported and preprocessed templates.
+    Limitation: master (inherited), imported and preprocessed templates.
 
-        It is recommended to use application server that supports
-        file reload instead.
+    It is recommended to use application server that supports
+    file reload instead.
     """
     if not enabled:
         return engine
